@@ -74,7 +74,7 @@ class CortxJupyter(ContentsManager):
         return _run_sync(file_exists_async)
 
     def get(self, path, content=True, type=None, format=None):
-        print('TESTING GET')
+        print('TESTI')
         print(path,content,type,format)
         @gen.coroutine
         def get_async():
@@ -131,21 +131,8 @@ class CortxJupyter(ContentsManager):
         with (yield self.write_lock.acquire()):
             return (yield _delete__notebook_checkpoint(self._config(), checkpoint_id, path))
 
-    @gen.coroutine
     def _config(self):
-        print('before')
-        cortx_auths = yield self.authentication.get_credentials()
-        print(cortx_auths)
-        print('type',type(cortx_auths))
-        creds = {'region_name':self.region_name,'bucket_name':self.bucket_name,
-        "host_name":self.host_name,"cortx_authenticator":cortx_auths._asdict(),
-        "prefix": self.prefix,"endpoint_url":self.endpoint_url
-        }
         
-        print(creds)
-        with open(".credentials", "w") as fp:
-            json.dump(creds , fp)
-
         return Config(
             region=self.region_name,
             bucket_name=self.bucket_name,
