@@ -647,7 +647,7 @@ def _get_all_keys(config, key_prefix, delimiter):
         directories.extend(directories_page)
 
     return keys, directories
-    
+
 READ_HELPERS = {
 ('directory', 'json'): _get_folder,
 ('notebook', 'json'): _get_notebook,
@@ -676,9 +676,6 @@ def _get_copy_key(key):
     return (key.count('/'), 0 if key.endswith(FOLDER_SEPERATOR) else 1)
 
 def _delete_copy_key(key):
-    copy_keys = []
-    for k in _get_copy_key(key):
-        return copy_keys.append(k*-1)
-    return tuple(copy_keys)
+    return tuple(-1 * key_i for key_i in _copy_sort_key(key))
 
 
